@@ -138,32 +138,32 @@
 <context>
     <name>DialogRecordDataExt</name>
     <message>
-        <location filename="DialogRecordDataExt.py" line="91"/>
+        <location filename="DialogRecordDataExt.py" line="93"/>
         <source>Attention! Data recording will continue to until it is stopped manually, or network interface will be deactivated.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="95"/>
+        <location filename="DialogRecordDataExt.py" line="97"/>
         <source>Data record is disabled</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="112"/>
+        <location filename="DialogRecordDataExt.py" line="114"/>
         <source>MAC address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="113"/>
+        <location filename="DialogRecordDataExt.py" line="115"/>
         <source>RX bytes/RX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="114"/>
+        <location filename="DialogRecordDataExt.py" line="116"/>
         <source>TX bytes/TX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="116"/>
+        <location filename="DialogRecordDataExt.py" line="118"/>
         <source>Network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -309,70 +309,75 @@ record</source>
 <context>
     <name>ListSessionsExt</name>
     <message>
-        <location filename="ListSessionsExt.py" line="107"/>
+        <location filename="ListSessionsExt.py" line="112"/>
         <source>Deleting sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="108"/>
+        <location filename="ListSessionsExt.py" line="113"/>
         <source>Delete selected sessions ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="172"/>
+        <location filename="ListSessionsExt.py" line="177"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="266"/>
+        <location filename="ListSessionsExt.py" line="276"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="267"/>
+        <location filename="ListSessionsExt.py" line="277"/>
         <source>Session does not contain data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="324"/>
+        <location filename="ListSessionsExt.py" line="334"/>
         <source>records</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="128"/>
+        <location filename="ListSessionsExt.py" line="133"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="129"/>
+        <location filename="ListSessionsExt.py" line="134"/>
         <source>Sorry, an error in the database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="362"/>
+        <location filename="ListSessionsExt.py" line="372"/>
         <source>Select a session to calculate the traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="367"/>
+        <location filename="ListSessionsExt.py" line="377"/>
         <source>Sessions:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="370"/>
+        <location filename="ListSessionsExt.py" line="380"/>
         <source>Full traffic:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="368"/>
+        <location filename="ListSessionsExt.py" line="378"/>
         <source>RX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="369"/>
+        <location filename="ListSessionsExt.py" line="379"/>
         <source>TX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ListSessionsExt.py" line="55"/>
+        <source>Loading...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -409,162 +414,162 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="156"/>
+        <location filename="OptionsWindow.py" line="202"/>
         <source>Frequency of data collection:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="157"/>
+        <location filename="OptionsWindow.py" line="186"/>
         <source>10 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="158"/>
+        <location filename="OptionsWindow.py" line="187"/>
         <source>15 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="159"/>
+        <location filename="OptionsWindow.py" line="188"/>
         <source>20 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="160"/>
+        <location filename="OptionsWindow.py" line="189"/>
         <source>30 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="161"/>
+        <location filename="OptionsWindow.py" line="190"/>
         <source>40 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="162"/>
+        <location filename="OptionsWindow.py" line="191"/>
         <source>60 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="163"/>
+        <location filename="OptionsWindow.py" line="207"/>
         <source>Database time limit:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="164"/>
+        <location filename="OptionsWindow.py" line="173"/>
         <source>2 weeks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="165"/>
+        <location filename="OptionsWindow.py" line="174"/>
         <source>1 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="166"/>
+        <location filename="OptionsWindow.py" line="175"/>
         <source>2 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="167"/>
+        <location filename="OptionsWindow.py" line="176"/>
         <source>3 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="168"/>
+        <location filename="OptionsWindow.py" line="177"/>
         <source>4 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="169"/>
+        <location filename="OptionsWindow.py" line="178"/>
         <source>5 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="170"/>
+        <location filename="OptionsWindow.py" line="179"/>
         <source>6 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="171"/>
+        <location filename="OptionsWindow.py" line="180"/>
         <source>9 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="172"/>
+        <location filename="OptionsWindow.py" line="181"/>
         <source>1 year</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="173"/>
+        <location filename="OptionsWindow.py" line="182"/>
         <source>not limited</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="174"/>
+        <location filename="OptionsWindow.py" line="201"/>
         <source>DateTime format:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="175"/>
+        <location filename="OptionsWindow.py" line="192"/>
         <source>YYYY-MM-DD HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="176"/>
+        <location filename="OptionsWindow.py" line="193"/>
         <source>MM-DD-YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="177"/>
+        <location filename="OptionsWindow.py" line="194"/>
         <source>DD-MM-YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="178"/>
+        <location filename="OptionsWindow.py" line="195"/>
         <source>DD.MM.YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="179"/>
+        <location filename="OptionsWindow.py" line="196"/>
         <source>MM.DD.YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="180"/>
+        <location filename="OptionsWindow.py" line="197"/>
         <source>YYYY.MM.DD HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="181"/>
+        <location filename="OptionsWindow.py" line="198"/>
         <source>DD/MM/YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="182"/>
+        <location filename="OptionsWindow.py" line="199"/>
         <source>MM/DD/YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="183"/>
+        <location filename="OptionsWindow.py" line="200"/>
         <source>YYYY/MM/DD HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="184"/>
+        <location filename="OptionsWindow.py" line="183"/>
         <source>Graphs colors:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="185"/>
+        <location filename="OptionsWindow.py" line="206"/>
         <source>RX</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="186"/>
+        <location filename="OptionsWindow.py" line="184"/>
         <source>TX</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="187"/>
+        <location filename="OptionsWindow.py" line="208"/>
         <source>Supported network interfaces:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -732,11 +737,6 @@ p, li { white-space: pre-wrap; }
         <source>Session end time</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="OptionsWindow.py" line="155"/>
-        <source>QNetMan (Settings)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="MainWindow.py" line="80"/>
         <source>Monitor 
@@ -758,42 +758,52 @@ connections</source>
         <source>Please, wait ...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="OptionsWindow.py" line="210"/>
+        <source>Enable root access ( restart needed )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="OptionsWindow.py" line="172"/>
+        <source>QNetMan (Settings)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowExt</name>
     <message>
-        <location filename="MainWindowExt.py" line="37"/>
+        <location filename="MainWindowExt.py" line="38"/>
         <source>Daemon QNetMan is not running.
 Start daemons now ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="38"/>
+        <location filename="MainWindowExt.py" line="39"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="43"/>
+        <location filename="MainWindowExt.py" line="44"/>
         <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="44"/>
+        <location filename="MainWindowExt.py" line="45"/>
         <source>Please restart the program now.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="47"/>
+        <location filename="MainWindowExt.py" line="48"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="48"/>
+        <location filename="MainWindowExt.py" line="49"/>
         <source>Failed to start daemon.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="51"/>
+        <location filename="MainWindowExt.py" line="52"/>
         <source>Features will be limited.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -801,17 +811,17 @@ Start daemons now ?</source>
 <context>
     <name>OptionsWindowExt</name>
     <message>
-        <location filename="OptionsWindowExt.py" line="298"/>
+        <location filename="OptionsWindowExt.py" line="300"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindowExt.py" line="283"/>
+        <location filename="OptionsWindowExt.py" line="285"/>
         <source>Should be left on at least one network interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindowExt.py" line="299"/>
+        <location filename="OptionsWindowExt.py" line="301"/>
         <source>Before you disable the network interface, turn off the record on this network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -972,73 +982,127 @@ Start daemons now ?</source>
         <source>Vladimir Sinichkin - for translation</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinAboutExt.py" line="147"/>
+        <source>Donate:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinAboutExt.py" line="148"/>
+        <source>You can donate to project via PayPal to qnetworkmanager@gmail.com</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WinNetStat</name>
     <message>
-        <location filename="WinNetStat.py" line="120"/>
+        <location filename="WinNetStatProc.py" line="105"/>
         <source>QNetMan (NetStat)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStat.py" line="121"/>
+        <location filename="WinNetStatProc.py" line="106"/>
         <source>Resolve</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStat.py" line="123"/>
-        <source>Auto
-refresh</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinNetStat.py" line="124"/>
-        <source>State</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinNetStat.py" line="125"/>
-        <source>Local Address</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinNetStat.py" line="126"/>
-        <source>Foreign Address</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinNetStat.py" line="127"/>
-        <source>Refresh</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinNetStat.py" line="128"/>
+        <location filename="WinNetStatProc.py" line="108"/>
         <source>Menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStat.py" line="129"/>
+        <location filename="WinNetStatProc.py" line="109"/>
         <source>Refresh interval</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinNetStatProc.py" line="107"/>
+        <source>Info</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
-    <name>WinNetStatExt</name>
+    <name>WinNetStatProcExt</name>
     <message>
-        <location filename="WinNetStatExt.py" line="229"/>
+        <location filename="WinNetStatProcExt.py" line="373"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatExt.py" line="230"/>
+        <location filename="WinNetStatProcExt.py" line="374"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatExt.py" line="240"/>
+        <location filename="WinNetStatProcExt.py" line="387"/>
         <source>Please, wait...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="403"/>
+        <source>Info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="417"/>
+        <source>Back</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="461"/>
+        <source>The device has received a connection request and send the acknowledgment. At the moment, is expected to start the connection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="464"/>
+        <source>The &quot;steady state&quot; of an open TCP connection. Data can be exchanged freely once both devices in the connection enter this state. This will continue until the connection is closed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="345"/>
+        <source>Information is not available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="453"/>
+        <source>Device (normally a server) is waiting for client connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="458"/>
+        <source>Device (normally a client) sent a request to connect to another device and is waiting for confirmation (normally from a server).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="467"/>
+        <source>One of the stages of closing the connection. Connection closing sent the request to the remote device.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="470"/>
+        <source>The last stage of closing the connection. Connection closing sent the request to the remote device.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="476"/>
+        <source>One of the stages of closing the connection. Connection closing sent the request to the local device.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="482"/>
+        <source>The last stage of closing the connection. After wait period, the device pass to the CLOSED state.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="485"/>
+        <source>This is the state by default before the connection is established. This is the sitation when there is no any connection between devices : it eather hasn&apos;t been created yet, or has just been broken.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="479"/>
+        <source>One of the stages of closing the connection. The simultaneous closure of the connection.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dlgNetworkSelect</name>
@@ -1079,4 +1143,42 @@ refresh</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>widgetViewInfoProc</name>
+    <message>
+        <location filename="widgetInfoProc.py" line="111"/>
+        <source>Form</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="widgetInfoProc.py" line="112"/>
+        <source>Process:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="widgetInfoProc.py" line="113"/>
+        <source>Pid of the process:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="widgetInfoProc.py" line="114"/>
+        <source>State:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="widgetInfoProc.py" line="115"/>
+        <source>Local address:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="widgetInfoProc.py" line="116"/>
+        <source>Foreign address:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="widgetInfoProc.py" line="117"/>
+        <source>Description:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
