@@ -6,7 +6,8 @@ from ViewCurrentSessionExt import ViewCurrentSessionExt
 from OptionsWindowExt import OptionsWindowExt
 from ListSessionsExt import ListSessionsExt
 from WinAboutExt import WinAboutExt
-from WinNetStatExt import WinNetStatExt
+#from WinNetStatExt import WinNetStatExt
+from WinNetStatProcExt import WinNetStatExt
 from QNMDBusClient import QNMDBusClient
 
 import myconfig
@@ -94,7 +95,7 @@ class MainWindowExt( QtGui.QMainWindow ):
 
 	def showConnections(self):
 		self.windowConnections.show()
-		self.windowConnections.showData()
+		#self.windowConnections.showData()
 	
 
 	def daemonStart(self):
