@@ -130,6 +130,8 @@ class OptionsWindowExt( QtGui.QMainWindow ):
 				self.ui.pb_eth0.setChecked( True )
 				flIfaceOn = True
 		
+		self.ui.cB_root.stateChanged.connect( self.rootAccessOnOff )
+		self.rootAccessCheck()
 		#все интерфейсы выключены. Неободим хотя бы один. По умолчанию gprs0
 		#if flIfaceOn == False:
 		#	self.ui.pb_gprs0.setChecked( True )
@@ -297,3 +299,22 @@ class OptionsWindowExt( QtGui.QMainWindow ):
 		txt1 = QtGui.QApplication.translate("OptionsWindowExt", "Warning", None, QtGui.QApplication.UnicodeUTF8)
 		txt2 = QtGui.QApplication.translate("OptionsWindowExt", "Before you disable the network interface, turn off the record on this network interface", None, QtGui.QApplication.UnicodeUTF8)
 		QtGui.QMessageBox.information( self, txt1, txt2 )
+
+	
+	def rootAccessOnOff(self, toggle):
+		file = myconfig.qnetman_home + ".rootenabled"
+		qf = QtCore.QFile( file )
+		if toggle:
+			qf.open( QtCore.QIODevice.WriteOnly )
+			qf.close()
+		else:
+			qf.remove()
+
+	def rootAccessCheck(self):
+		file = myconfig.qnetman_home + ".rootenabled"
+		if QtCore.QFile.exists( file ):
+			self.ui.cB_root.setCheckState( QtCore.Qt.Checked )
+			return True
+		else:
+			self.ui.cB_root.setCheckState( QtCore.Qt.Unchecked )
+			return False
