@@ -158,7 +158,22 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.noti = MyNotify()
 
 		self.dbusWaitDisplayOff()
+
+		#инициаизация приемников dbus сигналов от демона ( запуск/остановка записи )
+		self.session_bus = dbus.SessionBus( )
+		self.session_bus.add_signal_receiver( self.dbusSignalReceiver_recStarted, dbus_interface=None, signal_name="recStarted", bus_name="com.qnetman.Daemon", path="/QNetManDBus")
+		self.session_bus.add_signal_receiver( self.dbusSignalReceiver_recStoped, dbus_interface=None, signal_name="recStoped", bus_name="com.qnetman.Daemon", path="/QNetManDBus")
 	
+
+	#обработчкик dbus - сигналов запуска/остановки записи на сетевых интерфейсах
+	def dbusSignalReceiver_recStarted(self, iface):
+		self.statusRecDBus = self.mydbus.recStatus( self.iface ) #включена ли запись на сетевом интерфейсе
+		#print "dbusSignalReceiver_recStarted(%s)"%iface
+
+	def dbusSignalReceiver_recStoped(self, iface):
+		self.statusRecDBus = self.mydbus.recStatus( self.iface ) #включена ли запись на сетевом интерфейсе
+		#print "dbusSignalReceiver_recStoped(%s)"%iface
+
 	
 	def drawSystemCoord(self):
 		pen = QtGui.QPen( QtGui.QColor(100,100,100) )
@@ -635,7 +650,8 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 	def dlgRecordData(self):
 		self.dlgRec = QtGui.QDialog()
 		self.ui_dlgRec = DialogRecordDataExt.DialogRecordManagerExt( self.dlgRec, self.db, self.mydbus )
-		self.ui_dlgRec.stateRecordChange.connect( self.stateRecordChangeHere )
+		#XXX# вроде уже не нужно, т.к. изменение записи определяется приемом dbus сигналов
+		#self.ui_dlgRec.stateRecordChange.connect( self.stateRecordChangeHere )
 		self.dlgRec.show()
 		self.dlgRec.exec_()
 
