@@ -28,7 +28,7 @@ class WinAboutExt( QtGui.QMainWindow ):
 		self.createSlidingStackedWidget()
 
 		#XXX# Версия программы #XXX#
-		self.ui.lblVersionVal.setText("0.5.8")
+		self.ui.lblVersionVal.setText("0.6.4")
 
 		self.actionForm()
 
@@ -143,11 +143,15 @@ class WinAboutExt( QtGui.QMainWindow ):
 	def setContentP3(self):
 		txt1 = QtGui.QApplication.translate("WinAboutExt", "Licence:", None, QtGui.QApplication.UnicodeUTF8)
 		txt2 = QtGui.QApplication.translate("WinAboutExt", "GPL v2", None, QtGui.QApplication.UnicodeUTF8)
+		txt3 = QtGui.QApplication.translate("WinAboutExt", "Donate:", None, QtGui.QApplication.UnicodeUTF8)
+		txt4 = QtGui.QApplication.translate("WinAboutExt", "You can donate to project via PayPal to qnetworkmanager@gmail.com", None, QtGui.QApplication.UnicodeUTF8)
 		str  = "<html>"
 		str += "<div style='font-size: 14pt;'>"
 		str += "<p>%s</p>"%txt1
 		str += "<p>%s</p>"%txt2
 		str += "<p><a href='http://www.gnu.org/licenses/gpl.html'>http://www.gnu.org/licenses/gpl.html</a></p>"
+		str += "<p>%s</p>"%txt3
+		str += "<p>%s</p>"%txt4
 		str += "</div>"
 		str += "</html>"
 		self.tE_p3.setHtml( str )
