@@ -7,7 +7,7 @@ import myconfig
 
 class MyDB:
 	def __init__(self, filedb = myconfig.file_db):
-		self.mydb = sqlite3.connect(filedb)
+		self.mydb = sqlite3.connect(filedb, detect_types=1)
 		self.mydb.isolation_level = None #autocommit
 		self.cur = self.mydb.cursor()
 		self.createDB()
@@ -52,17 +52,23 @@ class MyDB:
 		sql_create_options += "'freq_traff_daemon' TEXT, "
 		sql_create_options += "'limit_size_db' TEXT"
 		sql_create_options += ");"
+		
+		sql_create_commentsession  = "CREATE TABLE IF NOT EXISTS 'main'.'commentsession' ( "
+		sql_create_commentsession += "'id' INTEGER UNIQUE PRIMARY KEY NOT NULL, "
+		sql_create_commentsession += "'session_id' INTEGER REFERENCES 'session' ('id') ON DELETE CASCADE ON UPDATE CASCADE, "
+		sql_create_commentsession += "'comment' TEXT NOT NULL);"
 
 		sql_alliface_gprs = "INSERT INTO 'main'.'alliface' (id, iface) VALUES (1, 'gprs0')"
 		sql_alliface_wlan = "INSERT INTO 'main'.'alliface' (id, iface) VALUES (2, 'wlan0')"
 		sql_alliface_usb =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (3, 'usb0')"
 		sql_alliface_pan =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (4, 'pan0')"
 		sql_alliface_eth =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (5, 'eth0')"
+		
 		try:
 			R = self.cur.execute(sql_pragma)
 		except Exception, E:
 			pass
-			#print "MyDB::createDB(): %s\n"%E
+			print "MyDB::createDB(): %s\n"%E
 		
 		try:
 			R = self.cur.execute(sql_create_type)
@@ -84,6 +90,11 @@ class MyDB:
 		except Exception, E:
 			print "MyDB::createDB(): [%s] %s\n"%(sql_create_options, E)
 		
+		try:
+			R = self.cur.execute(sql_create_commentsession)
+		except Exception, E:
+			print "MyDB::createDB(): [%s] %s\n"%(sql_create_options, E)
+
 		#--- alliface ---#
 		try:
 			R = self.cur.execute(sql_create_alliface)
@@ -206,22 +217,23 @@ class MyDB:
 	# возвращает список сессий за указанный период времени и типу трафика
 	def getListSession(self, type_session, start_time=None, end_time=None):
 		if start_time != None and end_time != None:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s' AND stop < '%s'"%( type_session, start_time, end_time )
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s' AND stop < '%s'"%( type_session, start_time, end_time )
 		elif start_time != None and end_time == None:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s'"%( type_session, start_time )
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s'"%( type_session, start_time )
 		elif start_time == None and end_time != None:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND stop < '%s'"%( type_session, end_time )
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND stop < '%s'"%( type_session, end_time )
 		else:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s"%type_session
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s"%type_session
 		
 		listReturn = []
 		try:
 			j = 0
 			for row in self.cur.execute( SQL ):
 				session = {}
-				session["start"] = row[0]
-				session["stop"] = row[1]
-				session["type_session"] = row[2]
+				session["session_id"] = row[0]
+				session["start"] = row[1]
+				session["stop"] = row[2]
+				session["type_session"] = row[3]
 				listReturn.append(session)
 				j += 1
 		except Exception, E:
@@ -233,22 +245,23 @@ class MyDB:
 	# возвращает список сессий за указанный период времени без типа трафика
 	def getFullListSession(self, start_time=None, end_time=None):
 		if start_time != None and end_time != None:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND start > '%s' AND stop < '%s'"%( start_time, end_time )
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND start > '%s' AND stop < '%s'"%( start_time, end_time )
 		elif start_time != None and end_time == None:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND start > '%s'"%( start_time )
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND start > '%s'"%( start_time )
 		elif start_time == None and end_time != None:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND stop < '%s'"%( end_time )
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND stop < '%s'"%( end_time )
 		else:
-			SQL = "select `start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL"
+			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL"
 		
 		listReturn = []
 		try:
 			j = 0
 			for row in self.cur.execute( SQL ):
 				session = {}
-				session["start"] = row[0]
-				session["stop"] = row[1]
-				session["type_session"] = row[2]
+				session["session_id"] = row[0]
+				session["start"] = row[1]
+				session["stop"] = row[2]
+				session["type_session"] = row[3]
 				listReturn.append(session)
 				j += 1
 		except Exception, E:
@@ -580,3 +593,49 @@ class MyDB:
 			ret = False
 
 		return ret
+
+
+	#--- коментарии к сессиям ---#
+	def getCommentSession( self, session_id ):
+		SQL = "SELECT comment FROM 'main'.'commentsession' WHERE session_id = %s;"%session_id
+		
+		ret = None
+
+		try:
+			self.cur.execute( SQL )
+			ret = self.cur.fetchone()[0]
+			if ret == None:
+				raise
+		except Exception, E:
+			print "MyDB::getCommentSession(): [%s] %s\n"%(SQL,E)
+			ret = None
+
+		return ret
+	
+
+	def setCommentSession(self, session_id, comment_text, comment_new = False ):
+		ok = True
+		try:
+			if comment_new:
+				self.cur.execute("INSERT INTO 'main'.'commentsession' (session_id, comment) VALUES (?, ?)", ( session_id, comment_text ) )
+			else:
+				self.cur.execute("UPDATE 'main'.'commentsession' SET comment=? WHERE session_id = ?;", ( comment_text, session_id ) )
+		except Exception, E:
+			print "MyDB::setCommentSession(): [%s] %s\n"%(SQL, E)
+			ok = False
+		return ok
+
+
+	def delCommentSession( self, session_id ):
+		SQL = "DELETE FROM 'main'.'commentsession' WHERE session_id = %s"%( session_id )
+		
+		ok = True
+		try:
+			self.cur.execute( SQL )
+		except Exception, E:
+			print "MyDB::delCommentSession(): [%s] %s\n"%(SQL, E)
+			ok = False
+		return ok
+
+	#----------------------#
+
